'use strict';
Object.defineProperty(exports, '__esModule', { value: true });
var prefix = 'fab';
var iconName = 'devpost';
var width = 512;
var height = 512;
var aliases = [];
var unicode = 'e8ae';
var svgPathData = 'M384 35L512 256 384 477 128 477 0 256 128 35 384 35zM162.6 120.8l0 270.3 79.8 0c69.2 0 137.7-40.6 137.7-135.2 0-98.5-57-135.2-133.9-135.2l-83.7 0zm81.7 53c57 0 80.6 27.2 80.6 82.2 0 49.1-26 82.2-82.4 82.2l-26.8 0 0-164.4 28.7 0z';

exports.definition = {
  prefix: prefix,
  iconName: iconName,
  icon: [
    width,
    height,
    aliases,
    unicode,
    svgPathData
  ]};

exports.faDevpost = exports.definition;
exports.prefix = prefix;
exports.iconName = iconName;
exports.width = width;
exports.height = height;
exports.ligatures = aliases;
exports.unicode = unicode;
exports.svgPathData = svgPathData;
exports.aliases = aliases;